@@ -5,21 +5,43 @@ use warnings;
 package Log::Any::Adapter::Stdout;
 
 # ABSTRACT: Simple adapter for logging to STDOUT
-our $VERSION = '0.91'; # TRIAL
+our $VERSION = '0.92'; # TRIAL
+
+use Log::Any::Adapter::Util ();
 
 use base qw/Log::Any::Adapter::Base/;
 
-foreach my $method ( Log::Any->logging_methods() ) {
-    no strict 'refs';
-    *{$method} = sub {
-        my ( $self, $text ) = @_;
-        print STDOUT "$text\n";
-      }
+my $trace_level = Log::Any::Adapter::Util::numeric_level('trace');
+
+sub init {
+    my ($self) = @_;
+    if ( exists $self->{log_level} ) {
+        $self->{log_level} =
+          Log::Any::Adapter::Util::numeric_level( $self->{log_level} )
+          unless $self->{log_level} =~ /^\d+$/;
+    }
+    else {
+        $self->{log_level} = $trace_level;
+    }
 }
 
-foreach my $method ( Log::Any->detection_methods() ) {
+foreach my $method ( Log::Any::Adapter::Util::logging_methods() ) {
     no strict 'refs';
-    *{$method} = sub { 1 };
+    my $method_level = Log::Any::Adapter::Util::numeric_level($method);
+    *{$method} = sub {
+        my ( $self, $text ) = @_;
+        return if $method_level > $self->{log_level};
+        print STDOUT "$text\n";
+    };
+}
+
+foreach my $method ( Log::Any::Adapter::Util::detection_methods() ) {
+    no strict 'refs';
+    my $base = substr( $method, 3 );
+    my $method_level = Log::Any::Adapter::Util::numeric_level($base);
+    *{$method} = sub {
+        return !!( $method_level <= $_[0]->{log_level} );
+    };
 }
 
 1;
@@ -36,7 +58,7 @@ Log::Any::Adapter::Stdout - Simple adapter for logging to STDOUT
 
 =head1 VERSION
 
-version 0.91
+version 0.92
 
 =head1 SYNOPSIS
 
@@ -48,10 +70,16 @@ version 0.91
     ...
     Log::Any::Adapter->set('Stdout');
 
+    # with minimum level 'warn'
+
+    use Log::Any::Adapter ('Stdout', log_level => 'warn' );
+
 =head1 DESCRIPTION
 
 This simple built-in L<Log::Any|Log::Any> adapter logs each message to STDOUT
-with a newline appended. Category and log level are ignored.
+with a newline appended. Category is ignored.
+
+The C<log_level> attribute may be set to define a minimum level to log.
 
 =head1 SEE ALSO
 
